# Workflow Framework Shell Scripts

These are non-python shell scripts used by some workflows. Use the table of
contents to jump to documentation for a specific script.

[[_TOC_]]

## framework.sh

This script ensures a workflow's directory structure is set up correctly for
CASA and CARTA processing. It is not typically run manually.

### Usage
```
Usage: framework [-d|-r|-wp] [parent_directory]

    This script sets up the directory structure required for CASA and CARTA processing.
    The path to the intended parent working directory is required when this script is called.

    Options:
    -d, --directory   parent_directory for CASA processing
    -r, --rawdata     make only rawdata directory in the given directory
    -wp, --workprod   make only working and products directories in the given directory
    -h, --help        display help and exit
    "
}
```

## ingest-request.sh

This script starts a calibration or image ingestion workflow, but is not
currently used by any workflows and typically not run manually.

### Usage
```
Usage: ingest-request [-c, -i] [workflow_request_id]

    This script sets off a Workspaces ingestion workflow of the specified type,
     given by the chosen option, for the provided workflow request id.

    Options:
    -c, --calibration   run the ingest_cal workflow for the specified request
    -i, --image         run the ingest_image workflow for the specified request
    -h, --help          display this help and exit
```

## ingest_vlass_epoch.sh

This script helps facilitate bulk ingestion of the VLASS quicklook image cache.
It looks inside the directory for a provided epoch project code and calls the
`ingest_vlass_tile.sh` script on each tile subdirectory. Accessing the vlass
tile ingest script requires the `CAPO_PROFILE` environment variable to be set.

### Usage
```
Usage: ingest_vlass_epoch PROJECT_CODE

    PROJECT_CODE: The project code with the tiles to be ingested
```

## ingest_vlass_tile.sh

This script calls the ```iiwf_trigger``` utility on every image directory within a
VLASS tile directory. It is not typically called by hand, but rather is a helper
script for `ingest_vlass_epoch.sh`. It requires the `CAPO_PROFILE` environment
variable be set.

### Usage
```
Usage: ingest_vlass_epoch PROJECT_CODE TILE_DIR
    PROJECT_CODE: The project code with the tiles to be ingested
    TILE_DIR: The tile directory with images to be ingested
```
